@@ -2,13 +2,12 @@ package WebService::OpenSky::Core::Flight;
 
 # ABSTRACT: Flight class
 
-use Moose;
-use experimental qw(signatures);
+use WebService::OpenSky::Moose;
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
-sub _get_params ($class) {
-    return qw(
+param [
+    qw(
       icao24
       firstSeen
       estDepartureAirport
@@ -21,11 +20,8 @@ sub _get_params ($class) {
       estArrivalAirportVertDistance
       departureAirportCandidatesCount
       arrivalAirportCandidatesCount
-    );
-}
-has [ __PACKAGE__->_get_params() ] => ( is => 'ro', required => 1 );
-
-__PACKAGE__->meta->make_immutable;
+    )
+];
 
 __END__
 
@@ -39,7 +35,7 @@ WebService::OpenSky::Core::Flight - Flight class
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
