@@ -2,9 +2,8 @@ package WebService::OpenSky::Core::StateVector;
 
 # ABSTRACT: A class representing a state from the OpenSky Network API
 
-use Moose;
-use experimental qw(signatures);
-our $VERSION = '0.2';
+use WebService::OpenSky::Moose;
+our $VERSION = '0.3';
 
 my @PARAMS = qw(
   icao24
@@ -27,19 +26,17 @@ my @PARAMS = qw(
   category
 );
 
+param [@PARAMS];
+
 around 'BUILDARGS' => sub ( $orig, $class, $state ) {
     my %value_for;
-    @value_for{ $class->_get_params } = @$state;
+    @value_for{@PARAMS} = @$state;
     return $class->$orig(%value_for);
 };
 
-has [@PARAMS] => ( is => 'ro', required => 1 );
+sub _get_params ($class) {@PARAMS}
 
-sub _get_params ($class) {
-    return @PARAMS;
-}
-
-sub category_name ($self) {
+method category_name() {
     my $category = $self->category // 0;
     $category = 0 if $category > 20;
     return '' unless $category;
@@ -69,7 +66,7 @@ sub category_name ($self) {
     return $names[$category];
 }
 
-sub position_source_name ($self) {
+method position_source_name() {
     my $source  = $self->position_source // return 'Uknown';
     my @sources = (
         'ADS-B',
@@ -80,8 +77,6 @@ sub position_source_name ($self) {
     return $sources[$source];
 }
 
-__PACKAGE__->meta->make_immutable;
-
 __END__
 
 =pod
@@ -94,7 +89,7 @@ WebService::OpenSky::Core::StateVector - A class representing a state from the O
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
