@@ -1,31 +1,29 @@
 package WebService::OpenSky::Core::Waypoint;
-#
+
 # ABSTRACT: Waypoint class
 
-use Moose;
-use experimental qw(signatures);
+use WebService::OpenSky::Moose;
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
-sub _get_params ($class) {
-    return qw(
-      time
-      latitude
-      longitude
-      baro_altitude
-      true_track
-      on_ground
-    );
-}
-has [ __PACKAGE__->_get_params() ] => ( is => 'ro', required => 1 );
+my @PARAMS = qw(
+  time
+  latitude
+  longitude
+  baro_altitude
+  true_track
+  on_ground
+);
+
+param [@PARAMS];
 
 around 'BUILDARGS' => sub ( $orig, $class, $waypoint ) {
     my %value_for;
-    @value_for{ $class->_get_params } = @$waypoint;
+    @value_for{@PARAMS} = @$waypoint;
     return $class->$orig(%value_for);
 };
 
-__PACKAGE__->meta->make_immutable;
+sub _get_params ($class) {@PARAMS}
 
 __END__
 
@@ -39,7 +37,7 @@ WebService::OpenSky::Core::Waypoint - Waypoint class
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
